package MyIR::Document;
use strict;
use warnings;
use base qw/Class::Accessor::Lvalue::Fast/;

__PACKAGE__->mk_accessors(qw/title content url doc_id score/);

use Path::Class qw/file/;
use Encode qw/encode_utf8 decode_utf8/;

use MyIR::DocID;

sub new_from_id {
    my ($self, $id) = @_;
    return $self->open($id);
}

sub save {
    my $self = shift;

    ## 保存時に新しい文書IDを付与する
    my $d = MyIR::DocID->new('./db/doc_id.txt');
    $self->doc_id = $d->incr_id;

    ## ./db/<doc_id> として保存
    my $fh = file(sprintf './db/%d', $self->doc_id)->openw;
    $fh->print($self->url, "\n");
    $fh->print(encode_utf8($self->title), "\n");
    $fh->print(encode_utf8($self->content));
    $fh->close;

    $d->save;

    return sprintf './db/%d', $self->doc_id;
}

sub open {
    my ($self, $id) = @_;
    my $fh = file(sprintf './db/%d', $id)->openr;
    my $doc = MyIR::Document->new;

    my $url   = $fh->getline;
    my $title = $fh->getline;

    my $content = '';
    while (defined(my $line = $fh->getline)) {
        $content .= $line;
    }
    $fh->close;

    chomp($url, $title, $content);

    $doc->doc_id  = $id;
    $doc->url     = $url;
    $doc->title   = decode_utf8($title);
    $doc->content = decode_utf8($content);

    return $doc;
}

1;
